#
# spec file for package libtomcrypt
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2009 Exata T.I., Maringa, PR, Brasil.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         soname libtomcrypt1
Name:           libtomcrypt
Version:        1.18.2
Release:        3.6
Summary:        Cryptographic Toolkit Written in Portable C
License:        SUSE-Public-Domain
Group:          Development/Libraries/C and C++
URL:            http://libtom.org
Source0:        https://github.com/libtom/libtomcrypt/releases/download/v%{version}/crypt-%{version}.tar.xz
Source1:        https://github.com/libtom/libtomcrypt/releases/download/v%{version}/crypt-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source4:        baselibs.conf
BuildRequires:  libtommath-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random number
generators, public key cryptography and a plethora of other routines.

%package -n %{soname}
Summary:        Cryptographic toolkit with ciphers, hashes, PRNG and PKI
Group:          System/Libraries

%description -n %{soname}
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains shared libraries

%package devel
Summary:        Development Files for LibTomCrypt
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description devel
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains headers and other development files.

%package examples
Summary:        Example Files for LibTomCrypt
Group:          Documentation/Other
Requires:       %{name}-devel = %{version}

%description examples
LibTomCrypt is a fairly comprehensive, modular and portable cryptographic
toolkit that provides developers with a vast array of well known published
block ciphers, one-way hash functions, chaining modes, pseudo-random
numbergenerators, public key cryptography and a plethora of other routines.

This package contains example *.c files showing how to use TomCrypt library.

%prep
%autosetup

%build
export CFLAGS="%{optflags} -DLTM_DESC -DUSE_LTM"
%make_build LIBPATH=%{_libdir} EXTRALIBS="-ltommath" -f makefile.shared

%install
%make_install -f makefile.shared DESTDIR=%{buildroot} LIBPATH=%{_libdir} NODOCS=0 PREFIX=%{_prefix}
# Remove static libraries (It's upstream bug in makefile.shared I think.)
rm %{buildroot}%{_libdir}/*.a
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build test CFLAGS="%{optflags}"
./test

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%{_libdir}/libtomcrypt.so.*
%license LICENSE
%doc README.md

%files devel
%attr(0644,root,root) %{_includedir}/tomcrypt*.h
%{_libdir}/libtomcrypt.so
%{_libdir}/pkgconfig/libtomcrypt.pc

%files examples
%doc demos

%changelog
* Sat Mar 18 2023 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Run tests during build
* Mon Sep 23 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove texlive BuildRequires, as the documentation is not built
- Drop manual __DATE__/__TIME__ mangling, SOURCE_DATE_EPOCH is
  respected by GCC for more than 3 years.
- Use license macro
* Wed Aug  8 2018 jengelh@inai.de
- Expand summary of libtomcrypt1.
- Use %%make_install.
* Thu Jul 26 2018 jengelh@inai.de
- Fix RPM groups.
- Don't pipe find, use the safer -exec.
* Thu Jul 12 2018 meissner@suse.com
- libtomcrypt.keyring: added key of new release manager 0xAF0CB17621EDAD72
- libtomcrypt-makefile.shared.patch: dropped
- reproducible.patch: dropped
* Mon Jul  2 2018 darin@darins.net
- v1.18.2
  - Fix Side Channel Based ECDSA Key Extraction (CVE-2018-12437) (PR #408)
  - Fix potential stack overflow when DER flexi-decoding (CVE-2018-0739) (PR #373)
  - Fix two-key 3DES (PR #390)
  - Fix accelerated CTR mode (PR #359)
  - Fix Fortuna PRNG (PR #363)
  - Fix compilation on platforms where cc doesn't point to gcc (PR #382)
  - Fix using the wrong environment variable LT instead of LIBTOOL (PR #392)
  - Fix build on platforms where the compiler provides __WCHAR_MAX__ but wchar.h is not available (PR #390)
  - Fix & re-factor crypt_list_all_sizes() and crypt_list_all_constants() (PR #414)
  - Minor fixes (PR's #350 #351 #375 #377 #378 #379)
  `
- Added libtommath-devl build requirement
- Added baselibs.conf
* Fri Jun 22 2018 darin@darins.net
- v1.18.1
  - Fix wrong SHA3 blocksizes, thanks to Claus Fischer for reporting this via Mail (PR #329)
  - Fix NULL-pointer dereference in `ccm_memory()` with LTC_CLEAN_STACK enabled (PR #327)
  - Fix `ccm_process()` being unable to process input buffers longer than 256 bytes (PR #326)
  - Fix the `register_all_{ciphers,hashes,prngs}()` return values (PR #316)
  - Fix some typos, warnings and duplicate prototypes in code & doc (PR's #310 #320 #321 #335)
  - Fix possible undefined behavior with LTC_PTHREAD (PR #337)
  - Fix some DER bugs (PR #339)
  - Fix CTR-mode when accelerator is used (OP-TEE/optee_os #2086)
  - Fix installation procedure (Issue #340)
* Wed Jul 12 2017 darin@darins.net
- udpate to version 1.18.0
- removed up upstream patches
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Fri Feb 12 2016 mpluskal@suse.com
- Use url for source
- Add gpg signature
- Cleanup spec file with spec-cleaner
- Do not include build date/time
* Tue Jul 15 2014 darin@darins.net
- cleaned up with spec-cleaner
- examples now require the devel package
* Fri Jul 11 2014 darin@darins.net
- do not package libtool archives
* Thu Jul  3 2014 darin@darins.net
- fix requires due to rename
* Thu Jul  3 2014 darin@darins.net
- add group to libtomcrypt0 package
* Thu Jul  3 2014 darin@darins.net
- rename to libtomcrypt.{spec,changes} and the patch,
  there's not osc move|copy so I just cp'd them.
- update packaging for share-lib policy
- fix license
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
- Add libtool as BuildRequires for factory/12.2
* Thu Aug 12 2010 alexandre@exatati.com.br
- Spec file cleaned with spec-cleaner.
